@@ -54,6 +54,7 @@
 #include "die.h"
 #include "find.h"
 #include "getdbpath.h"
+#include "gtagsop.h"
 #include "is_unixy.h"
 #include "langmap.h"
 #include "locatestring.h"
@@ -90,9 +91,6 @@
  */
 static regex_t *skip;			/**< regex for skipping units */
 static regex_t *suff;			/**< regex for suffixes */
-static STRBUF *list;
-static int list_count;
-static char **listarray;		/**< list for skipping full path */
 static FILE *ip;
 static FILE *temp;
 static char rootdir[PATH_MAX];
@@ -130,10 +128,46 @@ trim(char *s)
 	}
 	*p = 0;
 }
+/**
+ * get the reason for skipping
+ *
+ *	@param[in]	path	path name (must start with "./")
+ *	@return		<directory or not> | <reason for skipping>
+ *		directory or not: 1: directory, 0: file
+ *		reason: 1: dot file, 2: tag file, 0: others
+ */
+static int
+getreason(const char *path)
+{
+	int db, type = 0, is_directory = 0;
+	const char *p;
+
+	/* seek to the last character */
+	p = path + strlen(path) - 1;
+	if (*p == '/') {
+		is_directory = 1;
+		p--;
+	}
+	/* seek to the basename */
+	for (; path < p; p--)
+		if (*p == '/')
+			break;
+	if (*p == '/')
+		p++;
+	/* check for dot files */
+	if (*p == '.') {
+		type = 1;
+	} else {
+		/* check for tag files */
+		for (db = 0; db < GTAGLIM; db++)
+			if (!strcmp(dbname(db), p))
+				type = 2;
+	}
+	return is_directory << 8 | type;
+}
 /**
  * prepare_source: preparing regular expression.
  *
- *	<!-- @param[in]	flags	flags for regcomp. -->
  *	@return	compiled regular expression for source files.
  */
 static regex_t *
@@ -223,17 +257,6 @@ prepare_skip(void)
 #if defined(_WIN32) || defined(__DJGPP__)
 	flags |= REG_ICASE;
 #endif
-	/*
-	 * initialize common data.
-	 */
-	if (!list)
-		list = strbuf_open(0);
-	else
-		strbuf_reset(list);
-	list_count = 0;
-	if (listarray)
-		(void)free(listarray);
-	listarray = (char **)0;
 	/*
 	 * load skip data.
 	 */
@@ -242,10 +265,8 @@ prepare_skip(void)
 		return NULL;
 	}
 	skiplist = check_strdup(strbuf_value(reg));
-#ifdef DEGUB
 	if (debug)
-		fprintf(stderr, "original skip list: %s\n", skiplist);
-#endif
+		fprintf(stderr, "DBG: Original skip list:\n%s\n", skiplist);
 	/* trim(skiplist);*/
 	strbuf_reset(reg);
 	/*
@@ -284,95 +305,85 @@ prepare_skip(void)
 			strbuf_putc(sb, *p);
 		}
 		skipf = strbuf_value(sb);
+		/* '/' means project root directory */
 		if (*skipf == '/') {
-			list_count++;
-			strbuf_puts0(list, skipf);
+			strbuf_puts(reg, "^\\./");
+			skipf++;
 		} else {
 			strbuf_putc(reg, '/');
-			for (q = skipf; *q; q++) {
-				/*
-				 * replaces wild cards into regular expressions.
-				 *
-				 * '*' -> '.*'
-				 * '?' -> '.'
-				 * '[...]' -> '[...]'
-				 * '[!...]' -> '[^...]'
-				 */
-				if (*q == '[') {
-					char *c = q;
-					STATIC_STRBUF(class);
-					int isclass = 1;
+		}
+		for (q = skipf; *q; q++) {
+			/*
+			 * replaces wild cards into regular expressions.
+			 *
+			 * '*' -> '[^/]*'
+			 * '?' -> '[^/]'
+			 * '[...]' -> '[...]'
+			 * '[!...]' -> '[^...]'
+			 */
+			if (*q == '[') {
+				char *c = q;
+				STATIC_STRBUF(class);
+				int isclass = 1;
 
-					strbuf_clear(class);
-					strbuf_putc(class, *c++);		/* '[' */
-					if (*c == '\0')
+				strbuf_clear(class);
+				strbuf_putc(class, *c++);		/* '[' */
+				if (*c == '\0')
+					isclass = 0;
+				else if (*c == ']')
+					strbuf_putc(class, *c++);
+				else if (*c == '!') {
+					strbuf_putc(class, '^');
+					c++;
+				} else
+					strbuf_putc(class, *c++);
+				if (isclass) {
+					while (*c && *c != ']')
+						strbuf_putc(class, *c++);
+					if (*c == ']')
+						strbuf_putc(class, *c);	/* ']' */
+					else
 						isclass = 0;
-					else if (*c == ']')
-						strbuf_putc(class, *c++);
-					else if (*c == '!') {
-						strbuf_putc(class, '^');
-						c++;
-					} else
-						strbuf_putc(class, *c++);
-					if (isclass) {
-						while (*c && *c != ']')
-							strbuf_putc(class, *c++);
-						if (*c == ']')
-							strbuf_putc(class, *c);	/* ']' */
-						else
-							isclass = 0;
-					}
-					if (isclass) {
-						strbuf_puts(reg, strbuf_value(class));
-						q = c;
-					} else {
-						/* 'class' is thrown away */
-						strbuf_putc(reg, '\\');
-						strbuf_putc(reg, *q);
-					}
-				} else if (*q == '*')
-					strbuf_puts(reg, ".*");
-				else if (*q == '?')
-					strbuf_putc(reg, '.');
-				else if (*q == '\\' && *(q + 1) == ',')
-					strbuf_putc(reg, *++q);
-				else if (isregexchar(*q)) {
+				}
+				if (isclass) {
+					strbuf_puts(reg, strbuf_value(class));
+					q = c;
+				} else {
+					/* 'class' is thrown away */
 					strbuf_putc(reg, '\\');
 					strbuf_putc(reg, *q);
-				} else {
-					if (*q == '\\' && *(q + 1) != '\0') {
-						strbuf_putc(reg, *q++);
-						strbuf_putc(reg, *q);
-					} else
-						strbuf_putc(reg, *q);
 				}
+			} else if (*q == '*')
+				strbuf_puts(reg, "[^/]*");
+			else if (*q == '?')
+				strbuf_puts(reg, "[^/]");
+			else if (*q == '\\' && *(q + 1) == ',')
+				strbuf_putc(reg, *++q);
+			else if (isregexchar(*q)) {
+				strbuf_putc(reg, '\\');
+				strbuf_putc(reg, *q);
+			} else {
+				if (*q == '\\' && *(q + 1) != '\0') {
+					strbuf_putc(reg, *q++);
+					strbuf_putc(reg, *q);
+				} else
+					strbuf_putc(reg, *q);
 			}
-			if (*(q - 1) != '/')
-				strbuf_putc(reg, '$');
-			if (*p == ',')
-				strbuf_putc(reg, '|');
 		}
+		if (*(q - 1) != '/')
+			strbuf_putc(reg, '$');
+		if (*p == ',')
+			strbuf_putc(reg, '|');
 	}
 	strbuf_unputc(reg, '|');
 	strbuf_putc(reg, ')');
 	/*
 	 * compile regular expression.
 	 */
-#ifdef DEGUB
 	if (debug)
-		fprintf(stderr, "converted skip list:\n%s\n", strbuf_value(reg));
-#endif
+		fprintf(stderr, "DBG: Regular expression of the skip list:\n%s\n", strbuf_value(reg));
 	if (regcomp(&skip_area, strbuf_value(reg), flags) != 0)
 		die("cannot compile regular expression.");
-	if (list_count > 0) {
-		int i;
-		listarray = (char **)check_malloc(sizeof(char *) * list_count);
-		p = strbuf_value(list);
-		for (i = 0; i < list_count; i++) {
-			listarray[i] = p;
-			p += strlen(p) + 1;
-		}
-	}
 	strbuf_close(reg);
 	free(skiplist);
 
@@ -410,7 +421,7 @@ issourcefile(const char *path)
 int
 skipthisfile(const char *path)
 {
-	const char *first, *last;
+	regmatch_t m;
 	int i;
 
 	/*
@@ -421,35 +432,42 @@ skipthisfile(const char *path)
 		if (skip == NULL)
 			die("prepare_skip failed.");
 	}
-	if (regexec(skip, path, 0, 0, 0) == 0) {
-		if (find_explain)
-			fprintf(stderr, " File '%s' is skipped by skip variable (regex).\n", path);
-		return 1;
-	}
-	/*
-	 * list check.
-	 */
-	if (list_count == 0)
-		return 0;
-	for (i = 0; i < list_count; i++) {
-		first = listarray[i];
-		last = first + strlen(first);
-		/*
-		 * the path must start with "./".
-		 */
-		if (*(last - 1) == '/') {	/* it's a directory */
-			if (!STRNCMP(path + 1, first, last - first)) {
-				if (find_explain)
-					fprintf(stderr, " Directory '%s' is skipped by skip variable (path).\n", path);
-				return 1;
+	if (regexec(skip, path, 1, &m, 0) == 0) {
+		if (debug) {
+			int len = strlen(path);
+			fprintf(stderr, "DBG: ");
+			for (i = 0; i < len; i++) {
+				if (m.rm_so == i)
+					fputc('[', stderr);
+				if (m.rm_eo == i)
+					fputc(']', stderr);
+				fputc(path[i], stderr);
 			}
-		} else {
-			if (!STRCMP(path + 1, first)) {
-				if (find_explain)
-					fprintf(stderr, " File '%s' is skipped by skip variable (path).\n", path);
-				return 1;
+			if (m.rm_eo == len)
+				fputc(']', stderr);
+			fprintf(stderr, " => SKIPPED\n");
+		}
+		if (find_explain) {
+			int type = getreason(path);
+			const char *kind = (type >> 8) ? "Directory" : "File";
+
+			fprintf(stderr, " - %s '%s' is skipped", kind, trimpath(path));
+			switch (type & 0xff) {
+			case 1:
+				fprintf(stderr, " because the name begins with a dot.\n");
+				break;
+			case 2:
+				fprintf(stderr, " because it is a tag file.\n");
+				break;
+			case 0:		
+				fprintf(stderr, " by the skip list.\n");
+				break;
 			}
 		}
+		return 1;
+	} else {
+		if (debug)
+			fprintf(stderr, "%s\n", path);
 	}
 	return 0;
 }
