@@ -27,6 +27,7 @@
 #include <limits.h>
 #endif
 
+#include "char.h"
 #include "checkalloc.h"
 #include "die.h"
 #include "env.h"
@@ -142,11 +143,6 @@ repeat_find_next(void)
 /**
  * Common processing for each XARGS_XXXX type.
  */
-#ifdef _WIN32
-#define QUOTE	'"'
-#else
-#define QUOTE	'\''
-#endif
 #define APPEND_ARGUMENT(p) {\
 	char *path = (p);\
 	length = strlen(path);\
@@ -167,9 +163,7 @@ repeat_find_next(void)
 		if (xp->verbose)\
 			xp->verbose(path + 2, xp->seqno, 0);\
 		strbuf_putc(comline, ' ');\
-		strbuf_putc(comline, QUOTE);\
-		strbuf_puts(comline, path);\
-		strbuf_putc(comline, QUOTE);\
+		strbuf_puts(comline, quote_shell(path));\
 		count++;\
 	}\
 }
